@@ -6,6 +6,7 @@ import json
 import re
 import copy
 
+from six.moves import urllib
 import requests.models
 import requests
 from jsonpatch import make_patch
@@ -99,10 +100,6 @@ class S3PreparedRequest(requests.models.PreparedRequest):
             # <identifier>_meta.xml.
             if isinstance(meta_value, dict):
                 meta_value = json.dumps(meta_value)
-
-            # Replace \n with <br />.
-            meta_value = meta_value.replace('\n', '<br />')
-
             # Convert the metadata value into a list if it is not already
             # iterable.
             if not hasattr(meta_value, '__iter__'):
@@ -113,6 +110,8 @@ class S3PreparedRequest(requests.models.PreparedRequest):
                 if not value:
                     continue
                 header_key = 'x-archive-meta{0:02d}-{1}'.format(i, meta_key)
+                if any(c in value for c in ['\n', '\r']):
+                    value = 'uri({0})'.format(urllib.parse.quote(value))
                 # because rfc822 http headers disallow _ in names, IA-S3 will
                 # translate two hyphens in a row (--) into an underscore (_).
                 header_key = header_key.replace('_', '--')
